{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "name": "#types.cwl/ReadPair",
                            "type": "record",
                            "fields": [
                                {
                                    "type": "File",
                                    "name": "#types.cwl/ReadPair/in1"
                                },
                                {
                                    "type": [
                                        "null",
                                        "File"
                                    ],
                                    "name": "#types.cwl/ReadPair/in2"
                                }
                            ]
                        }
                    ],
                    "id": "#types.cwl"
                }
            ],
            "inputs": [
                {
                    "doc": "Blacklist regions to remove",
                    "type": "File",
                    "id": "#main/blacklist"
                },
                {
                    "doc": "Base filename of bwa index to map against",
                    "type": "File",
                    "id": "#main/idxbase"
                },
                {
                    "doc": "List of replicates",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "record",
                            "fields": [
                                {
                                    "doc": "Reads for control",
                                    "type": "#types.cwl/ReadPair",
                                    "name": "#main/replicates/control"
                                },
                                {
                                    "doc": "Reads for treatment",
                                    "type": "#types.cwl/ReadPair",
                                    "name": "#main/replicates/treatment"
                                }
                            ]
                        }
                    },
                    "id": "#main/replicates"
                }
            ],
            "steps": [
                {
                    "doc": "Align control reads for all replicates",
                    "run": "#chipseq_tf_align.cwl",
                    "in": [
                        {
                            "source": "#main/blacklist",
                            "id": "#main/align_control/blacklist"
                        },
                        {
                            "source": "#main/idxbase",
                            "id": "#main/align_control/idxbase"
                        },
                        {
                            "source": "#main/replicates",
                            "valueFrom": "$(self.control)",
                            "id": "#main/align_control/reads"
                        }
                    ],
                    "out": [
                        "#main/align_control/processed_reads"
                    ],
                    "scatter": [
                        "#main/align_control/reads"
                    ],
                    "id": "#main/align_control"
                },
                {
                    "doc": "Align treatment reads for all replictes",
                    "run": "#chipseq_tf_align.cwl",
                    "in": [
                        {
                            "source": "#main/blacklist",
                            "id": "#main/align_treatment/blacklist"
                        },
                        {
                            "source": "#main/idxbase",
                            "id": "#main/align_treatment/idxbase"
                        },
                        {
                            "source": "#main/replicates",
                            "valueFrom": "$(self.treatment)",
                            "id": "#main/align_treatment/reads"
                        }
                    ],
                    "out": [
                        "#main/align_treatment/processed_reads"
                    ],
                    "scatter": [
                        "#main/align_treatment/reads"
                    ],
                    "id": "#main/align_treatment"
                },
                {
                    "doc": "Run IDR analysis using pooled peaks as \"oracle\" peak list",
                    "run": "#idr.cwl",
                    "in": [
                        {
                            "source": "#main/pooled_call_peaks/narrowpeak_file",
                            "id": "#main/idr/peak-list"
                        },
                        {
                            "source": "#main/replicate_call_peaks/narrowpeak_file",
                            "id": "#main/idr/samples"
                        }
                    ],
                    "out": [
                        "#main/idr/output"
                    ],
                    "id": "#main/idr"
                },
                {
                    "doc": "Rename outputs to avoid conflicts",
                    "in": [
                        {
                            "source": "#main/idr/output",
                            "id": "#main/name_outputs/idr_narrowpeak_file"
                        },
                        {
                            "source": "#main/pooled_call_peaks/narrowpeak_file",
                            "id": "#main/name_outputs/pooled_narrowpeak_file"
                        },
                        {
                            "source": "#main/replicate_call_peaks/narrowpeak_file",
                            "id": "#main/name_outputs/replicate_narrowpeak_files"
                        }
                    ],
                    "out": [
                        "#main/name_outputs/out_replicate_narrowpeak_files",
                        "#main/name_outputs/out_pooled_narrowpeak_file",
                        "#main/name_outputs/out_idr_narrowpeak_file"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": "File",
                                "id": "#main/name_outputs/79d1b514-dfde-4668-98f2-235eb06077f3/idr_narrowpeak_file"
                            },
                            {
                                "type": "File",
                                "id": "#main/name_outputs/79d1b514-dfde-4668-98f2-235eb06077f3/pooled_narrowpeak_file"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/name_outputs/79d1b514-dfde-4668-98f2-235eb06077f3/replicate_narrowpeak_files"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#main/name_outputs/79d1b514-dfde-4668-98f2-235eb06077f3/out_idr_narrowpeak_file"
                            },
                            {
                                "type": "File",
                                "id": "#main/name_outputs/79d1b514-dfde-4668-98f2-235eb06077f3/out_pooled_narrowpeak_file"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/name_outputs/79d1b514-dfde-4668-98f2-235eb06077f3/out_replicate_narrowpeak_files"
                            }
                        ],
                        "expression": "${\nvar outputs = { \n    out_replicate_narrowpeak_files: inputs.replicate_narrowpeak_files,\n    out_pooled_narrowpeak_file: inputs.pooled_narrowpeak_file,\n    out_idr_narrowpeak_file: inputs.idr_narrowpeak_file\n}\noutputs.out_replicate_narrowpeak_files.forEach( function( e, i ) {\n  e.basename = \"Rep_\" + i.toString() + \".narrowPeak\";\n});\noutputs.out_pooled_narrowpeak_file.basename = \"Pooled.narrowPeak\";\noutputs.out_idr_narrowpeak_file.basename = \"Pooled_IDR.narrowPeak\";\nreturn outputs;\n}\n",
                        "id": "#main/name_outputs/79d1b514-dfde-4668-98f2-235eb06077f3"
                    },
                    "id": "#main/name_outputs"
                },
                {
                    "doc": "Call peaks on pooled reads",
                    "run": "#macs-callpeak.cwl",
                    "in": [
                        {
                            "source": "#main/pooled_replicates_control/output",
                            "id": "#main/pooled_call_peaks/control"
                        },
                        {
                            "source": "#main/pooled_replicates_treatment/output",
                            "id": "#main/pooled_call_peaks/treatment"
                        }
                    ],
                    "out": [
                        "#main/pooled_call_peaks/narrowpeak_file",
                        "#main/pooled_call_peaks/treatment_pileup_bdg"
                    ],
                    "id": "#main/pooled_call_peaks"
                },
                {
                    "doc": "Pool control reads for all replicates",
                    "run": "#samtools-merge.cwl",
                    "in": [
                        {
                            "source": "#main/align_control/processed_reads",
                            "id": "#main/pooled_replicates_control/input"
                        }
                    ],
                    "out": [
                        "#main/pooled_replicates_control/output"
                    ],
                    "id": "#main/pooled_replicates_control"
                },
                {
                    "doc": "Pool treatment reads for all replicates",
                    "run": "#samtools-merge.cwl",
                    "in": [
                        {
                            "source": "#main/align_treatment/processed_reads",
                            "id": "#main/pooled_replicates_treatment/input"
                        }
                    ],
                    "out": [
                        "#main/pooled_replicates_treatment/output"
                    ],
                    "id": "#main/pooled_replicates_treatment"
                },
                {
                    "doc": "Call peaks for replicates independently",
                    "run": "#macs-callpeak.cwl",
                    "in": [
                        {
                            "source": "#main/align_control/processed_reads",
                            "id": "#main/replicate_call_peaks/control"
                        },
                        {
                            "source": "#main/align_treatment/processed_reads",
                            "id": "#main/replicate_call_peaks/treatment"
                        }
                    ],
                    "out": [
                        "#main/replicate_call_peaks/narrowpeak_file"
                    ],
                    "scatter": [
                        "#main/replicate_call_peaks/treatment",
                        "#main/replicate_call_peaks/control"
                    ],
                    "scatterMethod": "dotproduct",
                    "id": "#main/replicate_call_peaks"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "doc": "Peaks surviving IDR using pooled peaks as oracle",
                    "type": "File",
                    "outputSource": "#main/name_outputs/out_idr_narrowpeak_file",
                    "id": "#main/idr_narrowpeak_file"
                },
                {
                    "doc": "Peaks for each replicate",
                    "type": "File",
                    "outputSource": "#main/name_outputs/out_pooled_narrowpeak_file",
                    "id": "#main/pooled_narrowpeak_file"
                },
                {
                    "doc": "Peaks from pooling replicates",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/name_outputs/out_replicate_narrowpeak_files",
                    "id": "#main/replicate_narrowpeak_files"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Blacklist regions to remove",
                    "type": "File",
                    "id": "#chipseq_tf_align.cwl/blacklist"
                },
                {
                    "doc": "Base filename of bwa index to map against",
                    "type": "File",
                    "id": "#chipseq_tf_align.cwl/idxbase"
                },
                {
                    "doc": "Reads to align",
                    "type": {
                        "type": "record",
                        "fields": [
                            {
                                "type": "File",
                                "name": "#chipseq_tf_align.cwl/reads/in1"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "name": "#chipseq_tf_align.cwl/reads/in2"
                            }
                        ]
                    },
                    "id": "#chipseq_tf_align.cwl/reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#chipseq_tf_align.cwl/remove_blacklist/output",
                    "id": "#chipseq_tf_align.cwl/processed_reads"
                }
            ],
            "steps": [
                {
                    "run": "#bwa-mem.cwl",
                    "in": [
                        {
                            "source": "#chipseq_tf_align.cwl/idxbase",
                            "id": "#chipseq_tf_align.cwl/align/idxbase"
                        },
                        {
                            "source": "#chipseq_tf_align.cwl/reads",
                            "id": "#chipseq_tf_align.cwl/align/reads"
                        }
                    ],
                    "out": [
                        "#chipseq_tf_align.cwl/align/output"
                    ],
                    "id": "#chipseq_tf_align.cwl/align"
                },
                {
                    "run": "#picard-MarkDuplicates.cwl",
                    "in": [
                        {
                            "source": "#chipseq_tf_align.cwl/sort/output",
                            "id": "#chipseq_tf_align.cwl/mark_duplicates/input"
                        }
                    ],
                    "out": [
                        "#chipseq_tf_align.cwl/mark_duplicates/output"
                    ],
                    "id": "#chipseq_tf_align.cwl/mark_duplicates"
                },
                {
                    "run": "#bedtools-intersect.cwl",
                    "in": [
                        {
                            "source": "#chipseq_tf_align.cwl/remove_unmapped/output",
                            "id": "#chipseq_tf_align.cwl/remove_blacklist/a"
                        },
                        {
                            "source": "#chipseq_tf_align.cwl/blacklist",
                            "id": "#chipseq_tf_align.cwl/remove_blacklist/b"
                        },
                        {
                            "valueFrom": "${ return true; }",
                            "id": "#chipseq_tf_align.cwl/remove_blacklist/v"
                        }
                    ],
                    "out": [
                        "#chipseq_tf_align.cwl/remove_blacklist/output"
                    ],
                    "id": "#chipseq_tf_align.cwl/remove_blacklist"
                },
                {
                    "run": "#samtools-view.cwl",
                    "in": [
                        {
                            "valueFrom": "4",
                            "id": "#chipseq_tf_align.cwl/remove_unmapped/filter_none_set"
                        },
                        {
                            "source": "#chipseq_tf_align.cwl/mark_duplicates/output",
                            "id": "#chipseq_tf_align.cwl/remove_unmapped/input"
                        }
                    ],
                    "out": [
                        "#chipseq_tf_align.cwl/remove_unmapped/output"
                    ],
                    "id": "#chipseq_tf_align.cwl/remove_unmapped"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#chipseq_tf_align.cwl/to_bam/output",
                            "id": "#chipseq_tf_align.cwl/sort/input"
                        }
                    ],
                    "out": [
                        "#chipseq_tf_align.cwl/sort/output"
                    ],
                    "id": "#chipseq_tf_align.cwl/sort"
                },
                {
                    "run": "#samtools-samtobam.cwl",
                    "in": [
                        {
                            "source": "#chipseq_tf_align.cwl/align/output",
                            "id": "#chipseq_tf_align.cwl/to_bam/input"
                        }
                    ],
                    "out": [
                        "#chipseq_tf_align.cwl/to_bam/output"
                    ],
                    "id": "#chipseq_tf_align.cwl/to_bam"
                }
            ],
            "id": "#chipseq_tf_align.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/bedtools:2.26.0gx--0",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "bedtools",
                            "version": [
                                "2.26.0gx"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": [
                "bedtools",
                "intersect"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-a",
                        "position": 2
                    },
                    "id": "#bedtools-intersect.cwl/a"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-b",
                        "position": 3
                    },
                    "id": "#bedtools-intersect.cwl/b"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "prefix": "-v"
                    },
                    "id": "#bedtools-intersect.cwl/v"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "#bedtools-intersect.cwl/bed",
                    "id": "#bedtools-intersect.cwl/output",
                    "outputBinding": {
                        "glob": "b527bf0c3ace1465f2ab0b3195757036105851e6"
                    }
                }
            ],
            "id": "#bedtools-intersect.cwl",
            "stdout": "b527bf0c3ace1465f2ab0b3195757036105851e6"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/bwa:0.7.15--0",
                    "class": "DockerRequirement"
                },
                {
                    "coresMax": 112,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "bwa",
                            "version": [
                                "0.7.15"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": [
                "bwa",
                "mem"
            ],
            "arguments": [
                {
                    "prefix": "-t",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bwa-mem.cwl/idxbase"
                },
                {
                    "type": {
                        "type": "record",
                        "fields": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 3
                                },
                                "name": "#bwa-mem.cwl/reads/in1"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "inputBinding": {
                                    "position": 4
                                },
                                "name": "#bwa-mem.cwl/reads/in2"
                            }
                        ]
                    },
                    "id": "#bwa-mem.cwl/reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "#bwa-mem.cwl/bam",
                    "id": "#bwa-mem.cwl/output",
                    "outputBinding": {
                        "glob": "3c4aac00ffac26fe3fc3e4ead727b60927c3014a"
                    }
                }
            ],
            "id": "#bwa-mem.cwl",
            "stdout": "3c4aac00ffac26fe3fc3e4ead727b60927c3014a"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/idr:2.0.3--py35_4",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "idr",
                            "version": [
                                "2.0.3"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": [
                "idr"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--peak-list",
                        "position": 2
                    },
                    "id": "#idr.cwl/peak-list"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "--samples",
                        "position": 1
                    },
                    "id": "#idr.cwl/samples"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#idr.cwl/log",
                    "outputBinding": {
                        "glob": "804f2addbda1400cb55f31c23ade7fcc04c7b48b"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "idrValues.txt"
                    },
                    "id": "#idr.cwl/output"
                }
            ],
            "id": "#idr.cwl",
            "stdout": "804f2addbda1400cb55f31c23ade7fcc04c7b48b"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/macs2:2.1.1.20160309--r3.2.2_0",
                    "class": "DockerRequirement"
                },
                {
                    "coresMax": 112,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "macs2",
                            "version": [
                                "2.1.1.20160309"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": [
                "macs2",
                "callpeak",
                "-B",
                "--outdir",
                "outdir"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-c"
                    },
                    "id": "#macs-callpeak.cwl/control"
                },
                {
                    "type": "string",
                    "default": "mm",
                    "id": "#macs-callpeak.cwl/genome_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-t"
                    },
                    "id": "#macs-callpeak.cwl/treatment"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "outdir/*_control_lambda.bdg"
                    },
                    "id": "#macs-callpeak.cwl/control_lambda_bdg"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "outdir/*_peaks.narrowPeak"
                    },
                    "id": "#macs-callpeak.cwl/narrowpeak_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "outdir/*_treat_pileup.bdg"
                    },
                    "id": "#macs-callpeak.cwl/treatment_pileup_bdg"
                }
            ],
            "id": "#macs-callpeak.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/picard:2.7.1--py27_0",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "picard",
                            "version": [
                                "2.9.2"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": [
                "picard",
                "MarkDuplicates",
                "OUTPUT=output.bam",
                "METRICS_FILE=metrics.txt"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "separate": false
                    },
                    "id": "#picard-MarkDuplicates.cwl/input"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "REMOVE_DUPLICATES=true",
                        "separate": false
                    },
                    "id": "#picard-MarkDuplicates.cwl/remove_duplicates"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "metrics.txt"
                    },
                    "id": "#picard-MarkDuplicates.cwl/metrics"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bam"
                    },
                    "id": "#picard-MarkDuplicates.cwl/output"
                }
            ],
            "id": "#picard-MarkDuplicates.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "samtools",
                            "version": [
                                "1.5"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "merge",
                "merged.bam"
            ],
            "arguments": [
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#samtools-merge.cwl/input"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "merged.bam"
                    },
                    "id": "#samtools-merge.cwl/output"
                }
            ],
            "id": "#samtools-merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "samtools",
                            "version": [
                                "1.5"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-b"
            ],
            "arguments": [
                {
                    "prefix": "-t",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools-samtobam.cwl/input"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools-samtobam.cwl/output",
                    "outputBinding": {
                        "glob": "f22c9200193c63484880f6ee6b5a60e2edf02991"
                    }
                }
            ],
            "id": "#samtools-samtobam.cwl",
            "stdout": "f22c9200193c63484880f6ee6b5a60e2edf02991"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "samtools",
                            "version": [
                                "1.5"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "arguments": [
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "prefix": "-T",
                    "valueFrom": "$TMPDIR"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools-sort.cwl/input"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools-sort.cwl/output",
                    "outputBinding": {
                        "glob": "ea34b777dbfb29eb67276293c89f94c04a8e5005"
                    }
                }
            ],
            "id": "#samtools-sort.cwl",
            "stdout": "ea34b777dbfb29eb67276293c89f94c04a8e5005"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "samtools",
                            "version": [
                                "1.5"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-b"
            ],
            "arguments": [
                {
                    "prefix": "-t",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    },
                    "id": "#samtools-view.cwl/filter_none_set"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#samtools-view.cwl/input"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools-view.cwl/output",
                    "outputBinding": {
                        "glob": "d0fef1c62cffde2f39fea34c69b1711eea514ed2"
                    }
                }
            ],
            "id": "#samtools-view.cwl",
            "stdout": "d0fef1c62cffde2f39fea34c69b1711eea514ed2"
        }
    ],
    "cwlVersion": "v1.0"
}
